// Countdown Timer Functionality
function initializeCountdownTimers() {
    const timers = document.querySelectorAll(".countdown-timer");
  
    timers.forEach((timer) => {
      const dateAttr = timer.getAttribute("data-date");
      const timeAttr = timer.getAttribute("data-time") || "00:00:00";
      const targetDate = new Date(`${dateAttr}T${timeAttr}`).getTime();
  
      if (isNaN(targetDate)) {
        console.error("Invalid date or time in data attributes:", dateAttr, timeAttr);
        return;
      }
  
      function swapNumbers(element, value, type) {
        const current = element.querySelector(`.current.${type}`);
        const next = element.querySelector(`.next.${type}`);
  
        // If value hasn't changed, no animation is needed
        if (current.textContent === value) return;
  
        // Update the next number and trigger animation
        next.textContent = value;
        current.classList.add("animate-out");
        next.classList.add("animate-in");
  
        // Wait for animation to finish, then swap roles
        setTimeout(() => {
          current.textContent = value; // Ensure current is updated
          current.classList.remove("animate-out");
          next.classList.remove("animate-in");
  
          // Swap current and next roles
          current.classList.remove("current");
          current.classList.add("next");
          next.classList.remove("next");
          next.classList.add("current");
        }, 500);
      }
  
      function updateCountdown() {
        const now = new Date().getTime();
        const difference = targetDate - now;
  
        if (difference <= 0) {
          clearInterval(interval);
          timer.querySelectorAll(".number-wrapper .current").forEach((span) => (span.textContent = "00"));
          alert("Countdown completed!");
          return;
        }
  
        const days = Math.floor(difference / (1000 * 60 * 60 * 24)).toString().padStart(2, "0");
        const hours = Math.floor((difference % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60)).toString().padStart(2, "0");
        const minutes = Math.floor((difference % (1000 * 60 * 60)) / (1000 * 60)).toString().padStart(2, "0");
        const seconds = Math.floor((difference % (1000 * 60)) / 1000).toString().padStart(2, "0");
  
        swapNumbers(timer.querySelector(".days").parentElement, days, "days");
        swapNumbers(timer.querySelector(".hours").parentElement, hours, "hours");
        swapNumbers(timer.querySelector(".minutes").parentElement, minutes, "minutes");
        swapNumbers(timer.querySelector(".seconds").parentElement, seconds, "seconds");
      }
  
      // Update every second
      const interval = setInterval(updateCountdown, 1000);
      updateCountdown(); // Initial call to display the countdown immediately
    });
  }
  
  // Initialize all countdown timers on page load
  document.addEventListener("DOMContentLoaded", initializeCountdownTimers);
  